bayespy.inference.vmp.nodes.gaussian.GaussianToGaussianGammaISO.plates_multiplier
=================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. autoattribute:: GaussianToGaussianGammaISO.plates_multiplier